==> pollen-ui-struts2-1.3.1.1-sources.jar: org/chorem/pollen/ui/actions/poll/SelectPersonListToVotingList.java <==
/*
 * #%L
 * Pollen :: UI (strust2)
 * 
 * $Id: SelectPersonListToVotingList.java 3394 2012-05-28 15:27:04Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.3.1.1/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/SelectPersonListToVotingList.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

import com.google.common.collect.Maps;
import org.chorem.pollen.PollenFunctions;
import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.business.persistence.UserAccount;
import org.chorem.pollen.services.impl.FavoriteService;
import org.chorem.pollen.ui.actions.PollenActionSupport;

import java.util.List;
import java.util.Map;

/**
 * Select a person list to add into an existing voting list.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class SelectPersonListToVotingList extends PollenActionSupport {

    private static final long serialVersionUID = 1L;

    protected String votingListType;

    protected int votingListNumber;

    protected String containerId;

    protected Map<String, PersonList> personList;

    public Map<String, PersonList> getPersonList() {
        return personList;
    }

    public int getVotingListNumber() {
        return votingListNumber;
    }

    public void setVotingListNumber(int votingListNumber) {
        this.votingListNumber = votingListNumber;
    }

    public String getVotingListType() {
        return votingListType;
    }

    public void setVotingListType(String votingListType) {
        this.votingListType = votingListType;
    }

    public String getContainerId() {
        return containerId;
    }

    public void setContainerId(String containerId) {
        this.containerId = containerId;
    }

    @Override
    public String execute() throws Exception {

        FavoriteService service = newService(FavoriteService.class);
        UserAccount userAccount = getPollenUserAccount();
        List<PersonList> personLists = service.getFavoriteLists(userAccount);

        personList = Maps.uniqueIndex(personLists, PollenFunctions.ENTITY_BY_ID);

        return SUCCESS;
    }
}

==> pollen-ui-struts2-1.4-sources.jar: org/chorem/pollen/ui/actions/poll/SelectPersonListToVotingList.java <==
/*
 * #%L
 * Pollen :: UI (struts2)
 * $Id: SelectPersonListToVotingList.java 3423 2012-06-05 16:50:22Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/pollen/tags/pollen-1.4/pollen-ui-struts2/src/main/java/org/chorem/pollen/ui/actions/poll/SelectPersonListToVotingList.java $
 * %%
 * Copyright (C) 2009 - 2012 CodeLutin, Tony Chemit
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.pollen.ui.actions.poll;

import com.google.common.collect.Maps;
import org.chorem.pollen.PollenFunctions;
import org.chorem.pollen.business.persistence.PersonList;
import org.chorem.pollen.business.persistence.UserAccount;
import org.chorem.pollen.ui.actions.PollenActionSupport;

import java.util.List;
import java.util.Map;

/**
 * Select a person list to add into an existing voting list.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.3
 */
public class SelectPersonListToVotingList extends PollenActionSupport {

    private static final long serialVersionUID = 1L;

    protected String votingListType;

    protected int votingListNumber;

    protected String containerId;

    protected Map<String, PersonList> personList;

    public Map<String, PersonList> getPersonList() {
        return personList;
    }

    public int getVotingListNumber() {
        return votingListNumber;
    }

    public void setVotingListNumber(int votingListNumber) {
        this.votingListNumber = votingListNumber;
    }

    public String getVotingListType() {
        return votingListType;
    }

    public void setVotingListType(String votingListType) {
        this.votingListType = votingListType;
    }

    public String getContainerId() {
        return containerId;
    }

    public void setContainerId(String containerId) {
        this.containerId = containerId;
    }

    @Override
    public String execute() throws Exception {

        UserAccount userAccount = getPollenUserAccount();
        List<PersonList> personLists =
                getFavoriteService().getFavoriteLists(userAccount);

        personList = Maps.uniqueIndex(personLists, PollenFunctions.ENTITY_BY_ID);

        return SUCCESS;
    }
}
